function [efr] = fjonswap(freq,alpha,fp,gamma,siga,sigb,ftail)
%
%  function [efr] = fjonswap(freq,alpha,fp,gamma,siga,sigb,ftail)
%
%  Compute JONSWAP spectrum for given set of parameters
%
%  Last update: 20 Feb. 2003
%
%     f        i    r
%     alpha    I    r   Energy scaling factor
%     fp       I    r   Peak frequency in Hz
%     gamma    I    r   Peak overshoot factor
%     siga     I    r   Spectral width, for F < FP
%     sigb     I    r   Spectral width, FOR F > FP
%     ftail    I    r   Power of tail of spectrum in frequency space, e.g. ftail= -4
%
%   Update history
%   20/2/2003   Made fully matrix scalable
%
eps  = 1.e-2;
rn   = 4.;
rm   = -ftail;
grav = 9.81;
%
izero = find(freq < 0.1*fp);
efr(izero) = 0;
sig = freq;
%if freq < 0.2*fp
%  efr = 0.0;
%  return
%else
%
  a  = alpha * grav^2/(2*pi)^4 * freq.^ftail;
  a  = a*fp^(rm-5);
%
  arg = -rm/rn*(fp./freq).^rn;
  b   = exp(arg);
%
  if abs(gamma-1) < eps
    efr = a.*b;
  else
    isiga = find(freq <= fp);      
    isigb = find(freq > fp)  ;    
    sig(isiga) = siga;
    sig(isigb) = sigb;   
%
    c = -0.5 * ((freq - fp)./(sig * fp)).^2;
    efr = a .* b.*gamma.^exp(c);
  end 
   
%
return

