function R=gamma_ratio(s)
%
% compute ratio of 2 gamma function values
% using a decomposition to avoid in accuracy due to
% machine precision. The following ratio appears
% in the normalisation of a cos^(2s)(theta/2) directional
% distribution
%
% gamma_ratio = gamma(s+1)/gamma(s+0.5)
%
% Gerbrant van Vledder
% 13 October 2015
%
% Use property  gamma(s+1)=s*gamma(s)
%
%   gamma(s+1)          s*gamma(s)         s*(s-1)*gamma(s-1)
% ------------ = -------------------- = -------------------------------
% gamma(s+0.5)   (s-0.5)*gamma(s-0.5)     (s-0.5)*(s-1.5)*gamma(s-1.5)
%
% a0 = gamma(s+1)/gamma(s+0.5)
if max(s) > 3
  ns = length(s);
  R  = s.*0+1;
  for is=1:ns
    if s(is)>3  
      ms     = ceil(s(is)-3);
      js     = 0:(ms-1);
      ratios = (s(is)-js)./(s(is)-js-0.5);
      R(is) = prod(ratios)*gamma(s(is)-ms+1)/gamma(s(is)-ms+0.5);
    else
      R(is) = gamma(s(is)+1)./gamma(s(is)+0.5);
    end
  end
%   uppers = (s-is)
%   lowers = (s-is-0.5)
%   up  = s-ns+1;
%   low = s-ns+0.5;
%   p   = prod(ratios);
else
  R = gamma(s+1)./gamma(s+0.5);
end